@@ -116,7 +116,7 @@ class Workbook(xmlwriter.XMLwriter):
         self.y_window = 15
         self.window_width = 16095
         self.window_height = 9660
-        self.tab_ratio = 500
+        self.tab_ratio = 600
         self.str_table = SharedStringTable()
         self.vba_project = None
         self.vba_is_stream = False
@@ -328,6 +328,26 @@ class Workbook(xmlwriter.XMLwriter):
         else:
             self.window_height = 9660
 
+    def set_tab_ratio(self, tab_ratio=None):
+        """
+        Set the ratio between worksheet tabs and the horizontal slider.
+
+        Args:
+            tab_ratio: The tab ratio, 0 <= tab_ratio <= 100
+
+        Returns:
+            Nothing.
+
+        """
+        if tab_ratio is None:
+            return
+
+        if tab_ratio < 0 or tab_ratio > 100:
+            warn("Tab ratio '%d' outside: 0 <= tab_ratio <= 100" % tab_ratio)
+            tab_ratio = 100
+        else:
+            self.tab_ratio = int(tab_ratio * 10)
+
     def set_properties(self, properties):
         """
         Set the document properties such as Title, Author etc.
@@ -655,27 +675,17 @@ class Workbook(xmlwriter.XMLwriter):
 
         xlsx_file.close()
 
-    def _add_sheet(self, name, is_chartsheet=None, worksheet_class=None):
+    def _add_sheet(self, name, worksheet_class=None):
         # Utility for shared code in add_worksheet() and add_chartsheet().
 
-        if is_chartsheet is not None:
-            warnings.warn(
-                "'is_chartsheet' has been deprecated and "
-                "may be removed in a future version. Use 'worksheet_class' "
-                "to get the same result",
-                PendingDeprecationWarning)
-
-        if is_chartsheet is None and worksheet_class is None:
+        if worksheet_class is None:
             raise ValueError(
-                "You must provide 'is_chartsheet' or 'worksheet_class'")
+                "_add_sheet() must define 'worksheet_class'")
 
         if worksheet_class:
             worksheet = worksheet_class()
         else:
-            if is_chartsheet:
-                worksheet = self.chartsheet_class()
-            else:
-                worksheet = self.worksheet_class()
+            worksheet = self.worksheet_class()
 
         sheet_index = len(self.worksheets_objs)
         name = self._check_sheetname(name, isinstance(worksheet, Chartsheet))
@@ -1653,7 +1663,7 @@ class Workbook(xmlwriter.XMLwriter):
         ]
 
         # Store the tabRatio attribute when it isn't the default.
-        if self.tab_ratio != 500:
+        if self.tab_ratio != 600:
             attributes.append(('tabRatio', self.tab_ratio))
 
         # Store the firstSheet attribute when it isn't the default.
